@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from dataclasses import dataclass
 from typing import TYPE_CHECKING, Generic, List, TypeVar
 
 from sila2.client.utils import call_rpc_function
@@ -12,6 +13,12 @@ if TYPE_CHECKING:
 T = TypeVar("T")
 
 
+@dataclass
+class ClientMetadataInstance(Generic[T]):
+    metadata: Metadata
+    value: T
+
+
 class ClientMetadata(Generic[T]):
     _parent_feature: ClientFeature
     _wrapped_metadata: Metadata
@@ -22,6 +29,9 @@ class ClientMetadata(Generic[T]):
         self._wrapped_metadata = wrapped_metadata
         self.fully_qualified_identifier = self._wrapped_metadata.fully_qualified_identifier
 
+    def __call__(self, value: T) -> ClientMetadataInstance[T]:
+        return ClientMetadataInstance(self._wrapped_metadata, value)
+
     def get_affected_calls(self) -> List[FullyQualifiedIdentifier]:
         param_msg = self._wrapped_metadata.get_affected_calls_parameters_message()
 
