@@ -13,8 +13,17 @@ class SilaDiscoveryBrowser(ServiceBrowser):
     listener: SilaServiceListener
     clients: List[SilaClient]
 
-    def __init__(self):
-        self.listener = SilaServiceListener(self)
+    def __init__(
+        self,
+        *,
+        insecure: bool = False,
+        root_certs: Optional[bytes] = None,
+        private_key: Optional[bytes] = None,
+        cert_chain: Optional[bytes] = None,
+    ):
+        self.listener = SilaServiceListener(
+            self, insecure=insecure, root_certs=root_certs, private_key=private_key, cert_chain=cert_chain
+        )
         super().__init__(Zeroconf(), "_sila._tcp.local.", self.listener)
 
     @property
@@ -38,3 +47,6 @@ class SilaDiscoveryBrowser(ServiceBrowser):
             time.sleep(0.1)
 
         raise TimeoutError(f"No suitable SiLA server was found after {timeout} seconds")
+
+    def __del__(self):
+        self.cancel()
