@@ -1,10 +1,9 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, List, Tuple
-
-from lxml import etree
+from typing import TYPE_CHECKING, List
 
 from sila2.framework.abc.constraint import Constraint
+from sila2.framework.data_types.any import SilaAnyType
 from sila2.framework.utils import xml_node_to_normalized_string, xpath_sila
 
 if TYPE_CHECKING:
@@ -18,8 +17,8 @@ class AllowedTypes(Constraint):
     def __init__(self, allowed_types: List[str]):
         self.allowed_types = allowed_types
 
-    def validate(self, value: Tuple[str, Any]) -> bool:
-        _type_str = xml_node_to_normalized_string(etree.fromstring(value[0]), remove_namespace=True)
+    def validate(self, value: SilaAnyType) -> bool:
+        _type_str = xml_node_to_normalized_string(value.type_xml, remove_namespace=True)
         return any(_type_str == s for s in self.allowed_types)
 
     @classmethod
