@@ -346,13 +346,13 @@ class FeatureImplementationServicer:
         for expected_meta_fqi in expected_metadata:
             if expected_meta_fqi not in received_metadata:
                 self.__raise_as_rpc_error(
-                    InvalidMetadata(f"Did not receive required metadata {expected_meta_fqi}"), context
+                    InvalidMetadata(f"Did not receive required metadata '{expected_meta_fqi}'"), context
                 )
 
         return received_metadata
 
     def __raise_as_rpc_error(self, error: SilaError, context: grpc.ServicerContext) -> NoReturn:
-        self.logger.error(f"Raising as RpcError {error!r}")
+        self.logger.error(f"Raising exception as RpcError: {error!r}")
         raise_as_rpc_error(error, context)
 
     def __get_observable_property_subscription_thread_for_queue(
